@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-09-29'; # DATE
-our $VERSION = '1.34'; # VERSION
+our $DATE = '2015-10-03'; # DATE
+our $VERSION = '1.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1399,7 +1399,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.34 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-09-29.
+This document describes version 1.35 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-10-03.
 
 =head1 DESCRIPTION
 
@@ -1605,7 +1605,7 @@ But this checking can be turned off with this setting. This is sometimes used
 when e.g. a subclass wants to pick a config profile automatically by setting C<<
 $r->{config_profile} >> somewhere before reading config file, but do not want to
 fail execution when config profile is not found. An example of code that does
-this is L<Perinci::CmdLine::fatten>.
+this is L<Perinci::CmdLine::depak>.
 
 =item * subcommand_name => str
 
